@@ -499,7 +499,7 @@
 
 #define SYSTEM_TYPE "Linux"
 #define MACHINE_TYPE "i686"
-/* #undef HAVE_DTRACE */
+#define HAVE_DTRACE 1
 
 #define SIGNAL_WITH_VIO_SHUTDOWN 1
 
@@ -646,16 +646,16 @@
 
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 49
+#define MYSQL_VERSION_PATCH 50
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.6.49"
+#define PACKAGE_STRING "MySQL Server 5.6.50"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.6.49"
-#define VERSION "5.6.49"
+#define PACKAGE_VERSION "5.6.50"
+#define VERSION "5.6.50"
 #define PROTOCOL_VERSION 10
 
 
